@@ -207,6 +207,22 @@ DOCUMENTATION__prepare = SwaggerDocumentation(
     )
 )
 
+DOCUMENTATION__domains = SwaggerDocumentation(
+    tags="Prepare",
+    methods=SwaggerMethod(
+        name="Fetches domains",
+        description="Fetches database level domains",
+        method=REST__POST,
+        body=SwaggerArgumentResponse(
+            name=KEY__database,
+            description="The database against which to fetch the domains",
+            arg_type=str,
+            example=["database"]
+        ),
+        response=RES__allow_all
+    )
+)
+
 DOCUMENTATION__set_web_config = SwaggerDocumentation(
     tags="Web Config",
     methods=SwaggerMethod(
